OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "L'obtencion dels getons de requèsta a fracassat. Verificatz que vòstra clau d'aplicacion e vòstre senhal son corrèctes.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "L'obtencion dels getons d'aacès a fracassat. Verificatz que vòstra clau d'aplicacion e vòstre senhal son corrèctes.",
    "Please provide a valid app key and secret." : "Provesissètz una clau d'aplicacion e un senhal valids.",
    "Step 1 failed. Exception: %s" : "L’etapa 1 a fracassat. Error : %s",
    "Step 2 failed. Exception: %s" : "L’etapa 2 a fracassat. Error : %s",
    "External storage" : "Emmagazinatge extèrne",
    "Dropbox App Configuration" : "Configuracion de l'aplicacion Dropbox",
    "Google Drive App Configuration" : "Configuracion de l'aplicacion Google Drive",
    "Personal" : "Personal",
    "System" : "Sistèma",
    "Grant access" : "Autorizar l'accès",
    "Error configuring OAuth1" : "Error al moment de la configuracion d'OAuth1",
    "Error configuring OAuth2" : "Error al moment de la configuracion d'OAuth2",
    "Generate keys" : "Generar de claus",
    "Error generating key pair" : "Error al moment de la generacion de las claus",
    "All users. Type to select user or group." : "Totes los utilizaires. Clicatz aicí per restrénher.",
    "(group)" : "(grop)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilitat amb l'encodatge Mac NFD (lent)",
    "Admin defined" : "Definit per l'administrator",
    "Saved" : "Enregistrat",
    "Empty response from the server" : "Responsa voida del servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Impossible d'accedir. Desconnectatz-vos e reconnectatz-vos per activar aqueste punt de montatge.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossible d'obténer l'informacion dempuèi lo servidor ownCloud : {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Impossible de recuperar la lista dels punts de montatge extèrnes : {type}",
    "There was an error with message: " : "I a agut una error amb lo messatge :",
    "External mount error" : "Error de punt de montatge extèrne",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossible d'obténer la lista dels punts de montatge dels disques rets Windows : Responsa voida del servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Certans punts de montatge extèrnes configurats son pas connectats. Clicatz sus la(s) linha(s) roja(s) per mai d'informacions",
    "Please enter the credentials for the {mount} mount" : "Entratz los identificants pel montatge {mount}",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "Credentials saved" : "Identificants salvats",
    "Credentials saving failed" : "Lo salvament dels identificants a fracassat",
    "Credentials required" : "D'informacions d'identificacion son requesidas",
    "Save" : "Enregistrar",
    "Storage with id \"%i\" not found" : "Emmagazinatge amb l'id \"%i\" pas trobat",
    "Invalid backend or authentication mechanism class" : "Servici o metòde d'autentificacion pas valable",
    "Invalid mount point" : "Punt de montatge invalid",
    "Objectstore forbidden" : "\"Objectstore\" interdich",
    "Invalid storage backend \"%s\"" : "Servici d'emmagazinatge invalid : \"%s\"",
    "Not permitted to use backend \"%s\"" : "Pas autorizat a utilizar lo servici \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Pas autorizat a utilizar lo mecanisme d'autentificacion \"%s\"",
    "Unsatisfied backend parameters" : "Paramètres mancants pel servici",
    "Unsatisfied authentication mechanism parameters" : "Paramètres mancants pel metòde d'autentificacion",
    "Insufficient data: %s" : "Donadas insufisentas : %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lo supòrt d'emmagazinatge d'id \"%i\" es pas modificable pels utilizaires",
    "Access key" : "Clau d'accès",
    "Secret key" : "Clau secreta",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "Clau API",
    "RSA public key" : "Clau publica RSA",
    "Public key" : "Clau publica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l'òste",
    "Port" : "Pòrt",
    "Region" : "Region",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Accès per path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sosdorsièr distant",
    "Secure https://" : "Securizacion https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Emplaçament",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Òste",
    "Root" : "Raiç",
    "SFTP with secret key login" : "SFTP amb un identificant secret",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partejar",
    "Domain" : "Domeni",
    "SMB / CIFS using OC login" : "SMB / CIFS en utilizant los identificants OC",
    "Username as share" : "Nom d'utilizaire coma nom de partiment",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom del servici",
    "Request timeout (seconds)" : "Timeout de las requèstas (en segondas)",
    "<b>Note:</b> " : "<b>Atencion :</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion :</b> La presa en carga de cURL per PHP es pas activada o installada. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Atencion : </b> \"%s\" es pas installat. Lo montatge de %s es pas possible. Contactatz vòstre administrator sistèma per l'installar.",
    "No external storage configured" : "Aucun emmagazinatge externe configurat",
    "Name" : "Nom",
    "Storage type" : "Tipe d'emmagazinatge",
    "Scope" : "Portada",
    "Enable encryption" : "Activar lo chiframent",
    "Enable previews" : "Activar las previsualizacions",
    "Enable sharing" : "Permetre lo partiment",
    "Check for changes" : "Recercar las modificacions",
    "Never" : "Pas jamai",
    "Once every direct access" : "Un còp a cada accès dirècte",
    "External Storage" : "Emmagazinatge externe",
    "Folder name" : "Nom del dorsièr",
    "Authentication" : "Autentificacion",
    "Configuration" : "Configuracion",
    "Available for" : "Disponible per",
    "Add storage" : "Apondre un supòrt d'emmagazinatge",
    "Advanced settings" : "Paramètres avançats",
    "Delete" : "Suprimir",
    "Allow users to mount external storage" : "Autorizar los utilizaires a montar l'espaci d'emmagazinatge extèrne",
    "Allow users to mount the following external storage" : "Autorizar los utilizaires a montar los emmagazinatges extèrnes seguents"
},
"nplurals=2; plural=(n > 1);");
